package com.ruoyi.orderManagement.BasicData.mapper;

import com.ruoyi.orderManagement.BasicData.domain.FleetDriverMsg;

import java.util.List;
import java.util.Map;


/**
 * 【司机】Mapper接口
 * 
 * @author ruoyi
 * @date 2021-03-04
 */
public interface FleetDriverMsgMapper 
{
    /**
     * 查询【司机】
     * 
     * @param id 【司机】ID
     * @return 【司机】
     */
    public FleetDriverMsg selectFleetDriverMsgById(Long id);

    /**
     * 查询【司机】列表
     * 
     * @param fleetDriverMsg 【司机】
     * @return 【司机】集合
     */
    public List<FleetDriverMsg> selectFleetDriverMsgList(FleetDriverMsg fleetDriverMsg);
    public List<Map<String, Object>>  selectFleetDriverMsgListMap(FleetDriverMsg fleetDriverMsg);
    /**
     * 新增【司机】
     * 
     * @param fleetDriverMsg 【司机】
     * @return 结果
     */
    public int insertFleetDriverMsg(FleetDriverMsg fleetDriverMsg);

    /**
     * 修改【司机】
     * 
     * @param fleetDriverMsg 【司机】
     * @return 结果
     */
    public int updateFleetDriverMsg(FleetDriverMsg fleetDriverMsg);

    /**
     * 删除【司机】
     * 
     * @param id 【司机】ID
     * @return 结果
     */
    public int deleteFleetDriverMsgById(Long id);

    /**
     * 批量删除【司机】
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteFleetDriverMsgByIds(Long[] ids);
}
